@@ -208,9 +208,10 @@ public class WorkSpaceSelectionCard extends WizardCard {
 		};
 
 		getWizardWindow().setPreviousButtonCommand(sayPreviousCard);
-		getWizardWindow().setEnableNextButton(true);
-		getWizardWindow().setEnableBackButton(true);
-
+		setBackButtonVisible(false);
+		setEnableBackButton(false);
+		setEnableNextButton(true);
+	
 	}
 
 	protected void goNext() {
